/* opengllib.h: functional interface to S2PLOT opengl helper functions
 *
 * ==================================================================
 * S2PLOT is freely available for non-commercial and educational use,
 * however, it is not public-domain software. The programming library
 * and documentation may not be redistributed or sub-licensed in any
 * form without permission from Swinburne University of
 * Technology. The programming library and sample codes are provided
 * without warranty.
 *
 * We would appreciate it if research outcomes using S2PLOT would
 * provide the following acknowledgement:
 *
 * "Three-dimensional visualisation was conducted with the S2PLOT
 * progamming library"
 *
 * and a reference to 
 *
 * D.G.Barnes, C.J.Fluke, P.D.Bourke & O.T.Parry, 2006, Publications
 * of the Astronomical Society of Australia, 23(2), 82-93.
 *
 * S2PLOT development was funded through the Researcher Developer
 * Grant Scheme at Swinburne University of Technology.
 * ==================================================================
 *
 * original version: Paul Bourke, pre 2005
 *
 * $Id: opengllib.h 5180 2008-06-06 03:39:59Z dbarnes $
 *
 */

#ifndef OPENGLLIB_H
#define OPENGLLIB_H

#if defined(__cplusplus)
extern "C" {
#endif

typedef struct {
	int id;
	char name[128];
} PANELITEM;
typedef struct {
	int id;
	int nitems;
	PANELITEM *items;
} PANEL;

int WindowDump(char *,int,int,int,int);
void ClearBuffers(int);
void ClearAllBuffers(void);
void CreateBox(XYZ,XYZ,int);
void CreateRegularGrid(XYZ,XYZ,int);
void CreatePolygon(XYZ *,XYZ *,COLOUR *,int);
void CreateSphere(XYZ,double,int,int,double,double,double,double);
void CreateSimpleSphere(XYZ,double,int,int);
void CreateSuperEllipse(double,double,int,int);
void EvalSuperEllipse(double,double,double,double,XYZ *);
void CreateEllipsoid(XYZ,double,int,double,double,double);
void CreateDisk(XYZ,XYZ,double,double,int,double,double);
void CreateCone(XYZ,XYZ,double,double,int,double,double);
void CreateTorus(XYZ,double,double,int,int,double,double,double,double,int);
void CreateStars(XYZ,double);
void CreateRandomStars(int);
BITMAP4 *ReadRawTexture(int,int,char *,COLOUR,int);
BITMAP4 *ReadPPMTexture(char *,COLOUR,int,int *,int *,int);
BITMAP4 *ReadTGATexture(char *,int *,int *);
BITMAP4 *ReadRawTexture2(int,int,char *,int);
void DrawGLText(int,int,char *);
void CreateLabelVector(char *,XYZ,XYZ,XYZ,XYZ *,int *);
void Draw3DPlus(XYZ,double);
void DrawAxes(XYZ,XYZ,int,int);
void Create3DCursor(int,int,int,int,XYZ,XYZ,XYZ,double,double);

#if defined(__cplusplus)
} // extern "C" {
#endif

#endif /* OPENGLLIB_H */
