/* s2const.h: public constants and definitions for S2PLOT library
 *
 * ==================================================================
 * S2PLOT is freely available for non-commercial and educational use,
 * however, it is not public-domain software. The programming library
 * and documentation may not be redistributed or sub-licensed in any
 * form without permission from Swinburne University of
 * Technology. The programming library and sample codes are provided
 * without warranty.
 *
 * We would appreciate it if research outcomes using S2PLOT would
 * provide the following acknowledgement:
 *
 * "Three-dimensional visualisation was conducted with the S2PLOT
 * progamming library"
 *
 * and a reference to 
 *
 * D.G.Barnes, C.J.Fluke, P.D.Bourke & O.T.Parry, 2006, Publications
 * of the Astronomical Society of Australia, 23(2), 82-93.
 *
 * S2PLOT development was funded through the Researcher Developer
 * Grant Scheme at Swinburne University of Technology.
 * ==================================================================
 *
 * original version: David Barnes, June 2007
 *
 * $Id: s2const.h 5284 2008-09-22 01:42:17Z dbarnes $
 *
 */

#ifndef S2CONST_H
#define S2CONST_H

/* Colours - based on PGPlot default settings */
#define S2_PG_BLACK 0
#define S2_PG_WHITE 1
#define S2_PG_RED   2
#define S2_PG_GREEN 3
#define S2_PG_BLUE  4
#define S2_PG_CYAN  5
#define S2_PG_MAGENTA 6
#define S2_PG_YELLOW 7
#define S2_PG_ORANGE 8
#define S2_PG_DKGRAY 14
#define S2_PG_DKGREY 14
#define S2_PG_LTGRAY 15
#define S2_PG_LTGREY 15

/* Rendering modes */
#define WIREFRAME      0
#define SHADE_FLAT     1
#define SHADE_DIFFUSE  2
#define SHADE_SPECULAR 3

/* Projections */
#define PERSPECTIVE 0
#define ORTHOGRAPHIC 1
#define FISHEYE 2

/* Stereo types */
#define NOSTEREO     0
#define ACTIVESTEREO 1
#define DUALSTEREO   2
#define ANAGLYPHSTEREO 3
#define TRIOSTEREO   4
#define INTERSTEREO  5
#define WDUALSTEREO  6

// Dome types */
#define NODOME      0
#define TRUNCBOTTOM 1
#define TRUNCTOP    2
#define VSPHERICAL  3
#define HSPHERICAL  4
#define WARPMAP     5
#define MIRROR1     6

// cursor types
#define S2_CURSOR_NONE 0
#define S2_CURSOR_CROSSHAIR 1
#define S2_SCREEN_WIDTH 0
#define S2_SCREEN_HEIGHT 1
#define S2_WINDOW_Y 2
#define S2_WINDOW_WIDTH 3
#define S2_WINDOW_HEIGHT 4


// these must map to GLUT values

// these must map to GLUT for s2glutwin to work! but could fix in future
// by writing s2swinGetModifiers() to translate
#define S2_ACTIVE_SHIFT 1
#define S2_ACTIVE_CTRL 2
#define S2_ACTIVE_ALT 4

// these must map to GLUT for s2glutwin to work!  but could fix in future
// by writing s2swinSpecial() ? to translate
#define S2_KEY_F1                     1
#define S2_KEY_F2                     2
#define S2_KEY_F3                     3
#define S2_KEY_F4                     4
#define S2_KEY_F5                     5 
#define S2_KEY_F6                     6
#define S2_KEY_F7                     7
#define S2_KEY_F8                     8
#define S2_KEY_F9                     9
#define S2_KEY_F10                    10
#define S2_KEY_F11                    11
#define S2_KEY_F12                    12
#define S2_KEY_LEFT                   100
#define S2_KEY_UP                     101
#define S2_KEY_RIGHT                  102
#define S2_KEY_DOWN                   103
#define S2_KEY_PAGE_UP                104
#define S2_KEY_PAGE_DOWN              105
#define S2_KEY_HOME                   106
#define S2_KEY_END                    107
#define S2_KEY_INSERT                 108

// and ditto for mouse buttons and states...
#define S2_LEFT_BUTTON                0
#define S2_MIDDLE_BUTTON              1
#define S2_RIGHT_BUTTON               2
#define S2_WHEEL_UP                   3
#define S2_WHEEL_DOWN                 4
#define S2_DOWN                       0
#define S2_UP                         1

// and ditto for visibility
#define S2_NOT_VISIBLE 0
#define S2_VISIBLE 1

#endif

